==> haskell-asn1-types-0.3.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-types
version: 0.3.3
id: asn1-types-0.3.3-9kOIcKUQpBeIUvQhC8COjO
key: asn1-types-0.3.3-9kOIcKUQpBeIUvQhC8COjO
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN.1 types
description:
    ASN.1 standard types
category: Data
abi: a5d2bf57f645ed58bada0a6bb5b1582c
exposed: True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-types-0.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-types-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-types-0.3.3
hs-libraries: HSasn1-types-0.3.3-9kOIcKUQpBeIUvQhC8COjO
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    hourglass-0.2.12-9lGYe4SnfHo7dk0TL2Yo4T
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html: /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-types-0.3.3-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-types
version: 0.3.3
id: asn1-types-0.3.3-4Uk1PObX3MW4QyDGQKlaYD
key: asn1-types-0.3.3-4Uk1PObX3MW4QyDGQKlaYD
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN.1 types
description:
    ASN.1 standard types
category: Data
abi: ea5e3f0dca8af1175faebf1a24274a87
exposed: True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-types-0.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-types-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-types-0.3.3
hs-libraries: HSasn1-types-0.3.3-4Uk1PObX3MW4QyDGQKlaYD
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    hourglass-0.2.12-IV73mzafuus4ZSHhtC19I2
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html: /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
